theme_white_f: theme_white_f is a 'ggplot2' theme function that can be added to a 'ggplot2'
object to eliminate axes, ticks and put white background
Description
theme_white_f is a 'ggplot2' theme function that can be added to a 'ggplot2'
object to eliminate axes, ticks and put white background
Usage
theme_white_f(base_size = 12, base_family = "")
Arguments
- base_size
base font size
- base_family
base font family