Learn R Programming

ggswissmaps (version 0.0.9)

shp_df: A list with 16 data frames of swiss territory boundaries, at various levels.

Description

Every element of the list is a data frame, which can be used with ggplot2.

Arguments

Format

A list with 16 data frames with swiss territory boundaries (at various levels).

Details

Columns are not all the same across data frames, but usually they have the following in common:
  • long. Longitude coordinate (x)
  • lat. Latitude coordinate (y)
  • group. A factor to be used to plot the polygons correctly (with ggplot2)

Examples

Run this code
data(shp_df)
class(shp_df)
length(shp_df)
names(shp_df)
str(shp_df[["g1k15"]])

Run the code above in your browser using DataLab